@@ -103,7 +103,7 @@ plot.estpoly <- function(x,newdata=NULL,...){
     time <- time(x$input)
     titstr <- "Predictions of Model on Training Set"
   } else{  
-    if(class(newdata)!="idframe") stop("Only idframe objects allowed")
+    if(!inherits(newdata, "idframe")) stop("Only idframe objects allowed")
     ypred <- predict(x,newdata)
     yact <- outputData(newdata)[,1]
     time <- time(newdata)
@@ -128,7 +128,7 @@ residplot <- function(model,newdata=NULL){
   if(is.null(newdata)){
     e <- resid(model); u <- model$input
   } else{
-    if(class(newdata)!="idframe") stop("Only idframe objects allowed")
+    if(!inherits(newdata, "idframe")) stop("Only idframe objects allowed")
     e <- newdata$output[,1] - predict(model,newdata)[,1]
     u <- newdata$input
   }
@@ -271,7 +271,7 @@ arx <- function(x,order=c(1,1,1),lambda=0.1,intNoise=FALSE,
   pinv <- innerinv%*% t(X)
   coef <- pinv%*%Y
   
-  eps <- X%*%coef
+  eps <- Y - X%*%coef
   sigma2 <- sum(eps^2)/(df+n)
   vcov <- sigma2 * innerinv
   fit <- (X%*%coef+fixedY)[1:N,,drop=F]
@@ -633,4 +633,4 @@ bj <- function(z,order=c(1,1,1,1,0),
           fitted.values=y-e,residuals=e,call=match.call(),input=u,
           options = options,termination = l$termination) 
 
-}
\ No newline at end of file
+}
